<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Programproxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valgfri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Tjek &quot;Brug en proxy&quot; i programmets genvejsmenu i opstarter efter den er blevet konfigureret</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ugyldig IP-adresse</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Ugyldig port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Er du sikker på, at du vil slette konfigurationen?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kablet forbindelse %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Trådløs forbindelse %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE-forbindelse %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Ny VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN-type</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportér</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programproxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Personligt hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netværksdetaljer</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kablet netværkskort</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tilføj netværksforbindelse</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Trådløst netværkskort</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Opret forbindelse til skjult netværk</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Opret PPPoE-forbindelse</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN-status</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Opret VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importér VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations-URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Opret hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grænseflade</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Bånd</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primær DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighed</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ikke bundet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhedens MAC-adresse</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonet MAC-adresse</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Brugerdefineret MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Navnet findes allerede</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Opret automatisk forbindelse</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Tilføj indstillinger</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Opret hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ugyldig IP-adresse</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ugyldig IP-adresse</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Kun anvendt i tilsvarende ressourcer</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Ugyldig IP-adresse</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Netværksdetaljer</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programproxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Netværksdetaljer</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiveret</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Konfigurer med netværkshåndtering</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Personligt hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Tjeneste</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Afvis EAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Afvis PAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Afvis CHAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Afvis MSCHAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Afvis MSCHAPv2-autentifikation</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD-datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen deflate-datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP-headerkomprimering</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen protokol-feltkomprimering</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen adresse-/kontrolkomprimering</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP echo-pakker</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Brug MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Opret PPPoE-forbindelse</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Systemproxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valgfri</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorer proxy-konfigurationerne for værterne og domænerne ovenfor</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations-URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Beskyttet EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiveret</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonym</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autentificeret</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Begge</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP-godkendelse</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Valgmuligheder for adgangskode</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat nøgle</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Brugercertifikat</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonym ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-fil</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Indre godkendelse</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-version</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat adgangskode</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ugyldig adgangskode</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 personlig</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Nøgle</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Påkrævet sikkerhed</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Ugyldig adgangskode</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 personlig</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Godkendelse</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Nøgle</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Avanceret VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Tilpas gateway-port</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway-port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Tilpas renegotiationsinterval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Renegotiationsinterval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Brug LZO-datakomprimering</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Brug TCP-forbindelse</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Brug TAP-enhed</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tilpas tunnel-MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Tilpas UDP-fragmentstørrelse</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-fragmentstørrelse</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Begræns tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Tilfældiggør fjern-værter</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Avanceret VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (standard)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sikker (standard)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Svag</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T når tilgængelig (standard)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T altid</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiveret</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH gruppe 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH gruppe 2 (standard)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH gruppe 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (standard)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH gruppe 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domæne</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Udbyder</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Kryptering</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT-gennemgangstilstand</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH-gruppe</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Videresende kode</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokal port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Deaktivér registrering af død peer</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Aktivér IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppenavn</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Gruppe-ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Prædelt nøgle</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Fase1-algoritmer</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Fase2-algoritmer</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certifikat</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Tillad Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD-skript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Brugercertifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat nøgle</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Brug FSID til nøgleadgangskode</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikater (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikater med adgangskode (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statisk nøgle</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gemt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrævet</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Godkendelsestype</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Brugercertifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat nøgle</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Valgmuligheder for adgangskode</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat adgangskode</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tilpas nøgleretning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nøgleretning</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Fjern-IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokal IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Alle tilgængelige (standard)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (mindre sikker)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (mest sikker)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Afvis EAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Afvis PAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Afvis CHAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Afvis MSCHAP-autentifikation</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Afvis MSCHAPv2-autentifikation</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD-datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen deflate-datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP-headerkomprimering</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen protokol-feltkomprimering</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen adresse-/kontrolkomprimering</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP echo-pakker</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Brug MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN-status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Opret VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importér VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Fejl ved import</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrævet</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Prøv igen når det fejler</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA-fil</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorer advarsler om certifikat</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Brug udvidelser for TLS-værtsnavn</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN-sikkerhed</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Chiffer</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC-godkendelse</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gemt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrævet</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Valgmuligheder for adgangskode</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT-domæne</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat nøgle</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smartcard</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Prædelt nøgle</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-certifikat</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Godkendelsestype</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Brugercertifikat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Anmod om en indre IP-adresse</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Gennemtving UDP-indkapsling</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Brug IP-komprimering</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Aktivér brugerdefineret cifferforslag</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS-autentifikation</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Emnematch</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Type af fjern-certifikat</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Nøglefil</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tilpas nøgleretning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nøgleretning</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Gemt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrævet</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Valgmuligheder for adgangskode</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppenavn</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Gruppens adgangskode</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Brug hybrid-autentifikation</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA-fil</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Tilslut venligst først netværkskablet</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kablet netværkskort</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Tilføj netværksforbindelse</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Vælg indstillinger</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Trådløst netværkskort</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Luk hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Deaktivér først hotspottet hvis du vil oprette forbindelse og bruger trådløst netværk</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Opret forbindelse til skjult netværk</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ikke bundet</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrævet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhedens MAC-adresse</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Brugerdefineret MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bånd</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grænseflade</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primær DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificering</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Indhenter IP-adresse</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Tilsluttet</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Afbrudt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislykkedet</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablet netværk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Trådløst netværk %1</translation>
    </message>
</context>
</TS>